import React from 'react';
import { Link } from 'react-router-dom';
import { Button, Tabs, Form, Space } from 'antd';
import { EditOutlined } from '@ant-design/icons';
import { ModalForm, ProFormDigit, ProFormText } from '@ant-design/pro-components';
import { getTaCheckItem, postTaCheckItem } from '@/service/tacheckitem';

const itemType = 'survey';

const SurveyForm = (props) => {
  const { checkId } = props;

  const [show, setShow] = React.useState(false);
  const [loading, setLoading] = React.useState(false);
  const [checkItem, setCheckItem] = React.useState();
  const [form] = Form.useForm();
  
  const onClick = (e) => {
    e.preventDefault();
    e.stopPropagation();
    setShow(true);
  }

  const onFinish = async (values) => {
    const data = { ...(checkItem || {}), ...values, itemType }
    const res = await postTaCheckItem(data);
    setCheckItem(res);
    form.setFieldsValue(res);
    return true;
  }

  const reset = () => {
    form.resetFields();
    form.setFieldsValue({ num: 1 });
  }

  React.useEffect(() => {
    if (checkItem) {
      form.setFieldsValue(checkItem);
    } else {
      reset();
    }
  }, [checkItem]);

  
  React.useEffect(() => {
    if (checkId) {
      setLoading(true);
      getTaCheckItem({ checkId, itemType }).then(res => {
        const item = (res.records || [])[0]
        if (item) {
          setCheckItem(item);
          form.setFieldsValue(item);
        }
        setLoading(false);
      }).catch(() => {
        setLoading(false);
      });
    }
  }, [checkId]);

  return (
    <ModalForm
      title={`问卷调查维护`}
      width={600}
      open={show}
      form={form}
      onFinish={onFinish}
      onOpenChange={setShow}
      trigger={(
        <>
          <div style={{ display: 'inline-block', marginLeft: '1em' }}>
            <Space>
              <span>
                <Link to={`/checkAnswer/survey?checkId=${checkId}&back=true`}>{checkItem?.answerNum || 0}</Link>
              </span>
              <span>/</span>
              <span>{`${checkItem?.num || 0} 份`}</span>
            </Space>
            
          </div>
          <Button type="link" size="middle" loading={loading} onClick={onClick}>
            <EditOutlined />
          </Button>
        </>
      )}
    >
      <ProFormDigit label="预收数量" name="num" min={1} fieldProps={{precision: 0}} />
      <ProFormText label="文明用语" name="cultureTerm"  fieldProps={{precision: 0}} />
    </ModalForm>
  )
}

export default SurveyForm;
